@@ -47,16 +47,19 @@ ci_vars <- c(
   "WERCKER_GIT_REPOSITORY" = NA,
   "WERCKER_MAIN_PIPELINE_STARTED" = NA)
 
-read_file <- function(file) paste(collapse = "\n", readLines(file))#readChar(file, file.info(file)$size)
+read_file <- function(file) paste(collapse = "\n", readLines(file))
+
+cov <- package_coverage("TestS4")
+
 test_that("coveralls generates a properly formatted json file", {
 
-  with_envvar(c(ci_vars, "CI_NAME" = "FAKECI"),
+  withr::with_envvar(c(ci_vars, "CI_NAME" = "FAKECI"),
     with_mock(
       `httr:::POST` = function(...) list(...),
       `httr::content` = identity,
       `httr::upload_file` = function(file) readChar(file, file.info(file)$size),
 
-      res <- coveralls("TestS4"),
+      res <- coveralls(coverage = cov),
       json <- jsonlite::fromJSON(res$body$json_file),
 
       expect_equal(nrow(json$source_files), 1),
@@ -64,7 +67,7 @@ test_that("coveralls generates a properly formatted json file", {
       expect_match(json$source_files$name, rex::rex("R", one_of("/", "\\"), "TestS4.R")),
       expect_equal(json$source_files$source, read_file("TestS4/R/TestS4.R")),
       expect_equal(json$source_files$coverage[[1]],
-        c(NA, NA, NA, NA, 5, 2, 5, 3, 5, NA, NA, NA, NA, NA, NA, NA, NA, NA,
+        c(NA, NA, NA, NA, NA, NA, 5, 2, NA, 3, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
           NA, NA, NA, NA, 1, NA, NA, NA, NA, NA, 1, NA, NA, NA, NA, NA, 1, NA))
     )
   )
@@ -72,14 +75,14 @@ test_that("coveralls generates a properly formatted json file", {
 
 test_that("coveralls can spawn a job using repo_token", {
 
-  with_envvar(c(ci_vars, "CI_NAME" = "DRONE"),
+  withr::with_envvar(c(ci_vars, "CI_NAME" = "DRONE"),
     with_mock(
       `httr:::POST` = function(...) list(...),
       `httr::content` = identity,
       `httr::upload_file` = function(file) readChar(file, file.info(file)$size),
-      `covr::system_output` = function(...) paste0(c("a","b","c","d","e","f"), collapse="\n"),
+      `covr::system_output` = function(...) paste0(c("a", "b", "c", "d", "e", "f"), collapse = "\n"),
 
-      res <- coveralls("TestS4", repo_token="mytoken"),
+      res <- coveralls(coverage = cov, repo_token = "mytoken"),
       json <- jsonlite::fromJSON(res$body$json_file),
 
       expect_equal(is.null(json$git), FALSE),
@@ -89,7 +92,7 @@ test_that("coveralls can spawn a job using repo_token", {
       expect_match(json$source_files$name, rex::rex("R", one_of("/", "\\"), "TestS4.R")),
       expect_equal(json$source_files$source, read_file("TestS4/R/TestS4.R")),
       expect_equal(json$source_files$coverage[[1]],
-        c(NA, NA, NA, NA, 5, 2, 5, 3, 5, NA, NA, NA, NA, NA, NA, NA, NA, NA,
+        c(NA, NA, NA, NA, NA, NA, 5, 2, NA, 3, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
           NA, NA, NA, NA, 1, NA, NA, NA, NA, NA, 1, NA, NA, NA, NA, NA, 1, NA))
     )
   )
@@ -97,9 +100,9 @@ test_that("coveralls can spawn a job using repo_token", {
 
 test_that("generates correct payload for Drone and Jenkins", {
 
-  with_envvar(c(ci_vars, "CI_NAME" = "FAKECI", "CI_BRANCH" = "fakebranch", "CI_REMOTE" = "covr"),
+  withr::with_envvar(c(ci_vars, "CI_NAME" = "FAKECI", "CI_BRANCH" = "fakebranch", "CI_REMOTE" = "covr"),
     with_mock(
-      `covr::system_output` = function(...) paste0(c("a","b","c","d","e","f"), collapse="\n"),
+      `covr::system_output` = function(...) paste0(c("a", "b", "c", "d", "e", "f"), collapse = "\n"),
       git <- jenkins_git_info(),
 
       expect_equal(git$head$id, jsonlite::unbox("a")),
